package net.sf.saxon.functions;
import net.sf.saxon.codenorm.Normalizer;
import net.sf.saxon.expr.XPathContext;
import net.sf.saxon.om.Item;
import net.sf.saxon.trans.DynamicError;
import net.sf.saxon.trans.XPathException;
import net.sf.saxon.value.StringValue;

/**
 * Implement the XPath normalize-unicode() function
 */

public class NormalizeUnicode extends SystemFunction {

    /**
    * Evaluate in a general context
    */

    public Item evaluateItem(XPathContext c) throws XPathException {
        StringValue sv = (StringValue)argument[0].evaluateItem(c);
        if (sv==null) {
            return StringValue.EMPTY_STRING;
        }
        byte fb = Normalizer.C;
        if (argument.length == 2) {
            String form = argument[1].evaluateAsString(c);
            if (form.equals("NFC")) {
                fb = Normalizer.C;
            } else if (form.equals("NFD")) {
                fb = Normalizer.D;
            } else if (form.equals("NFKC")) {
                fb = Normalizer.KC;
            } else if (form.equals("NFKD")) {
                fb = Normalizer.KD;
            } else {
                String msg = "Normalization form " + form + " is not supported";
                DynamicError err = new DynamicError(msg);
                err.setErrorCode("FOCH0003");
                err.setXPathContext(c);
                throw err;
            }
        }
        Normalizer norm = new Normalizer(fb);
        String result = norm.normalize(sv.getStringValue());
        return StringValue.makeStringValue(result);
    }

}




//
// The contents of this file are subject to the Mozilla Public License Version 1.0 (the "License");
// you may not use this file except in compliance with the License. You may obtain a copy of the
// License at http://www.mozilla.org/MPL/
//
// Software distributed under the License is distributed on an "AS IS" basis,
// WITHOUT WARRANTY OF ANY KIND, either express or implied.
// See the License for the specific language governing rights and limitations under the License.
//
// The Original Code is: all this file.
//
// The Initial Developer of the Original Code is Michael H. Kay.
//
// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved.
//
// Contributor(s): none.
//
